@@ -17,8 +17,8 @@ visualizations_dir <- args[2]
 setwd(results_dir)
 
 ## Troubleshooting ##
-#setwd('/Users/owlex/Dropbox/Documents/Northwestern/Hartmann_Lab/syntenease_project/gtr/testbed/dataset2/test1/pdua/results') #debugging
-#visualizations_dir <- '/Users/owlex/Dropbox/Documents/Northwestern/Hartmann_Lab/syntenease_project/gtr/testbed/dataset2/test1/pdua/visualizations' #debugging
+#setwd('/Users/owlex/Dropbox/Documents/Northwestern/Hartmann_Lab/syntenease_project/gtr/testbed/dataset4/test1/mexb/results') #debugging
+#visualizations_dir <- '/Users/owlex/Dropbox/Documents/Northwestern/Hartmann_Lab/syntenease_project/gtr/testbed/dataset4/test1/mexb/visualizations' #debugging
 ## ## ## ## ## ## ## ##
 
 # dataframe with scaling parameters for each
@@ -189,7 +189,7 @@ for (ch in unique(df_chunk_order$chunk_group)){
   
   
   p7 <- plot_grid(p3_ggid,p1_ggregions,p2_ggdis,align='hv',nrow=1,rel_widths = c(0.25,0.5,0.25), axis='bt')
-  save_plot(paste(visualizations_dir,'/multiplot_repregions_', ch,'.png',sep='') ,p7,base_height=8,base_aspect_ratio = 2)
+  save_plot(paste(visualizations_dir,'/group_summary_', ch,'.png',sep='') ,p7,base_height=8,base_aspect_ratio = 2)
 }
 
 
@@ -219,7 +219,7 @@ p1_taxafound <- ggplot(df_meta, aes(x=genus_dummy,y=value,fill=variable))+
         strip.background = element_blank(),
         strip.text.x = element_blank())+
   ylab(label='Count')
-save_plot(paste(visualizations_dir,'/taxa_found.png',sep=''),p1_taxafound,base_height=8,base_aspect_ratio = 2)
+save_plot(paste(visualizations_dir,'/taxa_searched.png',sep=''),p1_taxafound,base_height=8,base_aspect_ratio = 2)
 
 
 #### Plot percentage of hits per cluster per taxa ####
@@ -293,7 +293,7 @@ for (ch in unique(df_chunk_order$chunk_group)){
     
   
   p8 <- plot_grid(p3_region_taxa_breakdown, p4_empty, align='hv',nrow=1,rel_widths = c(0.98,0.05), axis='bt')
-  save_plot(paste(visualizations_dir,'/region_taxa_breakdown_',ch,'.png',sep=''),p8,base_height=8,base_aspect_ratio = 2)
+  save_plot(paste(visualizations_dir,'/groups_by_taxa_',ch,'.png',sep=''),p8,base_height=8,base_aspect_ratio = 2)
   
 }
 
